# Copyright (C) 2020 Majormode.  All rights reserved.
#
# This software is the confidential and proprietary information of
# Majormode or one of its subsidiaries.  You shall not disclose this
# confidential information and shall use it only in accordance with the
# terms of the license agreement or other applicable agreement you
# entered into with Majormode.
#
# MAJORMODE MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
# OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
# TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE, OR NON-INFRINGEMENT.  MAJORMODE SHALL NOT BE LIABLE FOR ANY
# LOSSES OR DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
# OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.

import collections

from majormode.mercurius.constant.place import AddressComponentName
from majormode.perseus.model.geolocation import GeoPoint
from majormode.perseus.model.locale import Locale
from majormode.perseus.utils import cast


class BusStop:
    def __eq__(self, other):
        return self.__location == other.__location

    def __hash__(self):
        return hash(self.__location)

    def __init__(
            self,
            stop_code,
            location,
            address=None,
            boundaries=None,
            stop_id=None):
        self.__stop_code = stop_code
        self.__location = location
        self.__address = address
        self.__boundaries = boundaries
        self.__stop_id = stop_id

    @property
    def address(self):
        return self.__address

    @property
    def boundaries(self):
        return self.__boundaries

    @property
    def location(self):
        return self.__location

    @property
    def stop_code(self):
        return self.__stop_code

    @property
    def stop_id(self):
        return self.__stop_id

    @stop_id.setter
    def stop_id(self, stop_id):
        if self.__stop_id:
            raise AttributeError(f'this bus stop is already defined with the identifier "{self.__stop_id}"')
        self.__stop_id = stop_id


class BusStopJson(BusStop):
    def __init__(
            self,
            stop_code,
            location,
            address=None,
            stop_id=None):
        super().__init__(stop_code, location, address=address, stop_id=stop_id)

    @staticmethod
    def __parse_address(payload):
        address = collections.defaultdict(dict)
        if payload:
            for locale_str, address_components in payload.items():
                locale = Locale.from_string(locale_str)
                for component_name_str, component_value in address_components.items():
                    component_name = cast.string_to_enum(component_name_str, AddressComponentName)
                    address[locale][component_name] = component_value
        return address

    @classmethod
    def from_json(cls, payload):
        return payload and BusStopJson(
            payload['stop_code'],
            GeoPoint.from_json(payload['location']),
            address=cls.__parse_address(payload.get('address')),
            stop_id=cast.string_to_uuid(payload.get('stop_id'), strict=False))


class BusLine:
    def __init__(self, name, journey_type, stops, path, line_id=None):
        if any([not isinstance(stop, BusLineStop) for stop in stops]):
            raise TypeError("items of argument 'stop' MUST all be 'BusLineStop' objects")

        self.__name = name
        self.__journey_type = journey_type
        self.__stops = stops
        self.__path = path
        self.__line_id = line_id

    @property
    def journey_type(self):
        return self.__journey_type

    @property
    def line_id(self):
        return self.__line_id

    @line_id.setter
    def line_id(self, line_id):
        if self.__line_id:
            raise AttributeError(f'already defined with the identifier "{self.__line_id}"')
        self.__line_id = line_id

    @property
    def name(self):
        return self.__name

    @property
    def path(self):
        return self.__path

    @property
    def stops(self):
        return self.__stops


class BusLineStop:
    def __init__(self, stop_id, arrival_time=None, departure_time=None):
        self.__stop_id = stop_id
        self.__arrival_time = arrival_time
        self.__departure_time = departure_time

    @property
    def arrival_time(self):
        return self.__arrival_time

    @property
    def departure_time(self):
        return self.__departure_time

    @property
    def stop_id(self):
        return self.__stop_id





# class BusLineJson(BusLine):
#     # def __init__(self, journey_type, stops, path, route_id=None):
#     #     super().__init__(journey_type, stops, path, route_id=route_id)
#     @staticmethod
#     def __parse_path(payload):
#         path = [
#             GeoPoint.from_json(point)
#             for point in payload
#         ]
#         return path
#
#     @staticmethod
#     def __parse_bus_stops(payload):
#         bus_stops = [
#             BusLineStopJson.from_json(bus_stop_payload)
#             for bus_stop_payload in payload
#         ]
#         return bus_stops
#
#     @classmethod
#     def from_json(cls, payload):
#         print(payload['stops'])
#         return payload and BusLineJson(
#             payload['name'],
#             cast.string_to_enum(payload['trip_type'], TripDirection),
#             cls.__parse_bus_stops(payload['stops']),
#             cls.__parse_path(payload['path']),
#             line_id=cast.string_to_uuid(payload.get('line_id'), strict=False))
#
#
# class BusLineStopJson(BusLineStop):
#     @staticmethod
#     def from_json(payload):
#         return payload and BusLineStopJson(
#             cast.string_to_uuid(payload['stop_id']),
#             arrival_time=cast.string_to_time(payload['arrival_time']),
#             departure_time=cast.string_to_time(payload['departure_time']))
#
#
# class BusLineStopJson(BusStop):
#     def __init__(self, stop_id, location, scheduled_time):
#         super().__init__(location, stop_id=stop_id)
#         self.__scheduled_time = scheduled_time
#
#     @classmethod
#     def from_json(cls, payload):
#         return payload and BusLineStopJson(
#             GeoPoint.from_json(payload['location']))
#         stop_code = placemark.name.text
#         location = cls._parse_location(placemark.Point.coordinates.text)
#         return BusLineStopJson(stop_code, location, scheduled_time)
#
#     @property
#     def scheduled_time(self):
#         return self.__scheduled_time








# Copyright (C) 2019 Majormode.  All rights reserved.
#
# This software is the confidential and proprietary information of
# Majormode or one of its subsidiaries.  You shall not disclose this
# confidential information and shall use it only in accordance with the
# terms of the license agreement or other applicable agreement you
# entered into with Majormode.
#
# MAJORMODE MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
# OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
# TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE, OR NON-INFRINGEMENT.  MAJORMODE SHALL NOT BE LIABLE FOR ANY
# LOSSES OR DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
# OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.

from majormode.perseus.constant.obj import ObjectStatus
from majormode.perseus.model.enum import Enum


IDReaderDeviceNotification = Enum(
    # Indicate that the state of a ID-R device's battery has changed.  This
    # device has been connected to or disconnected from an external power
    # source.
    'on_battery_state_changed',

    # Indicate that the battery level of a ID-R device went down a critical
    # threshold.
    'on_battery_level_critical'

    # Indicate that a ID-R device has been activated by an administrator of the
    # organization that manages this device.
    'on_device_activated',

    # Indicate that a ID-R device sent a handshake while it was not yet
    # registered to the platform.  Its activation stays pending until an
    # administrator of the organization, which manages the place where
    # the ID-R device shakes-hands at, reviews this request.
    'on_device_activation_requested',

    # Indicate that the attributes of a ID-R device have been updated.
    # This notification includes the list of properties that have been
    # updated, and their new respective values.
    'on_device_attributes_updated',
)

# Define constants specifying actions to change the status of a ID-R
# device of an organisation.
IDReaderDeviceStatusChangeAction = Enum(
    'reactivate',
    'remove',
    'suspend',
)

# Define the new status of a ID-R device depending on the action that
# was performed.
IDReaderDeviceStatusChangeResult = {
    IDReaderDeviceStatusChangeAction.reactivate: ObjectStatus.enabled,
    IDReaderDeviceStatusChangeAction.suspend: ObjectStatus.disabled,
    IDReaderDeviceStatusChangeAction.remove: ObjectStatus.deleted,
}



# Copyright (C) 2019 Majormode.  All rights reserved.
#
# This software is the confidential and proprietary information of
# Majormode or one of its subsidiaries.  You shall not disclose this
# confidential information and shall use it only in accordance with the
# terms of the license agreement or other applicable agreement you
# entered into with Majormode.
#
# MAJORMODE MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
# OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
# TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE, OR NON-INFRINGEMENT.  MAJORMODE SHALL NOT BE LIABLE FOR ANY
# LOSSES OR DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
# OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.

from majormode.perseus.constant.team import MemberRole
from majormode.perseus.model.enum import Enum

TeamRole = Enum(
    # Organization responsible for registering and managing families to
    # the transportation service of the school campus, such as a parent
    # association when the school organization itself doesn't manage the
    # transportation service of its campus.
    'manager',

    # Organization that has not particular responsibility on the
    # transportation service of a school campus, but that is allowed to
    # monitor the transportation service's activities of the school.
    'observer',

    # Organization that owns the school campus, i.e., the education
    # institution itself (the school organization).
    'owner',

    # Organization responsible for operating the transportation service of
    # the children to the school campus. The user MUST be the director of
    # this organization.
    'transporter',
)

TeamMemberRole = MemberRole.extend(
    # An administrator is responsible for managing the Xebus Workspace of
    # their organization.
    'administrator',
    
    # An attendant, also known as *bus monitor*, is responsible for checking
    # in and checking out the pupils when they get on and off the school bus.
    'attendant',

    # A coordinator is responsible for a team of attendants.
    'coordinator',

    # A driver is responsible for riding the pupils back and forth from
    # their home (or the closest bus stop) to the school campus.
    'driver',

    # A security guard is responsible for checking in and checking out the
    # pupils when they enter and leave the school campus.
    'security_guard',
)



# Copyright (C) 2019 Majormode.  All rights reserved.
#
# This software is the confidential and proprietary information of
# Majormode or one of its subsidiaries.  You shall not disclose this
# confidential information and shall use it only in accordance with the
# terms of the license agreement or other applicable agreement you
# entered into with Majormode.
#
# MAJORMODE MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
# OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
# TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE, OR NON-INFRINGEMENT.  MAJORMODE SHALL NOT BE LIABLE FOR ANY
# LOSSES OR DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
# OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.

import re

from majormode.perseus.model.locale import Locale


ENGLISH_LOCALE = Locale('eng')
FRENCH_LOCALE = Locale('fra')
KOREAN_LOCALE = Locale('kor')
VIETNAMESE_LOCALE = Locale('vie')


def format_first_name(first_name, locale=None):
    """
    Format the first name according to the locale.

    All the name components of French, English, and Vietnamese first names
    are capitalized, while the rest of the words are lower cased.  Korean
    personal names are not transformed.


    @param first_name: Forename (also known as *given name*) of the person.
        The first name can be used to alphabetically sort a list of users.

    @param locale: An object `Locale` that supposedly refers to the name
        of this person.


    @return: The formatted first name of the person.
    """
    first_name_ = normalize_name(first_name)
    return ' '.join([
        component.lower().capitalize()
        for component in first_name_.split()
    ])


def format_full_name(last_name, first_name, locale=None):
    """
    Format the full name according to the locale.

    For French and English personal names, first name comes first, and
    last name comes last.  While for Vietnamese and Korean, this order is
    reversed.


    @param last_name: Surname (also known as *family name*) of the person.
        The last name can be used to alphabetically sort a list of users.

    @param first_name: Forename (also known as *given name*) of the person.
        The first name can be used to alphabetically sort a list of users.

    @param locale: An object `Locale` that supposedly refers to the name
        of this person.


    @return: The formatted full name of the person.
    """
    return f'{first_name} {last_name}' if locale is None or locale in (FRENCH_LOCALE, ENGLISH_LOCALE) \
        else f'{last_name} {first_name}'


def format_last_name(last_name, locale=None):
    """
    Format the last name according to the locale.

    French, English, and Vietnamese personal names are converted to upper
    case.  However, Korean personal names are not upper cased.


    @param last_name: Surname (also known as *family name*) of the person.
        The last name can be used to alphabetically sort a list of users.

    @param locale: An object `Locale` that supposedly refers to the name
        of this person.


    @return: The formatted last name of the person.
    """
    last_name_ = normalize_name(last_name)
    return last_name_.upper()


def normalize_name(name):
    """
    Remove any punctuation and duplicated space characters.


    @param name: A surname, a forename, or a full name of a person.


    @return: The given name that has been cleansed from useless characters.
    """
    # Replace any punctuation character with space.
    punctuationless_string = re.sub(r'[.,\\/#!$%^&*;:{}=\-_`~()<>"\']', ' ', name)

    # Remove any duplicate space characters.
    return ' '.join(punctuationless_string.split())



# Copyright (C) 2020 Majormode.  All rights reserved.
#
# This software is the confidential and proprietary information of
# Majormode or one of its subsidiaries.  You shall not disclose this
# confidential information and shall use it only in accordance with the
# terms of the license agreement or other applicable agreement you
# entered into with Majormode.
#
# MAJORMODE MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
# OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
# TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE, OR NON-INFRINGEMENT.  MAJORMODE SHALL NOT BE LIABLE FOR ANY
# LOSSES OR DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
# OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.

from majormode.perseus.model.enum import Enum


# Indicate the type of bus stop suggestion made based on the school buses
# activities of a school.
BusStopSuggestionType = Enum(
    # Suggest a new bus stop as Ci/Co operations have been recorded at a
    # geographical location where no bus stops have been registered nearby.
    'creation',

    # Suggest a shift of the geographical location of an existing bus stop
    # as Ci/Co operations have been recorded at another location near to
    # this bus stop.
    'shift',

    # Suggest the deletion of an existing bus stop as no Ci/Co operations
    # have been recorded for a while at the geographical location of the
    # bus stop.
    'deletion',
)

# Indicate the direction of a school bus trip.
TripDirection = Enum(
    # From home to school.
    'outward',

    # From school to home.
    'inward',
)

# Indicate the direction of the school bus route passing through a bus
# stop.
BusStopTripDirection = TripDirection.extend(
    # Could be used for routes from home to school or from school to home.
    'mixed'
)


# Copyright (C) 2020 Majormode.  All rights reserved.
#
# This software is the confidential and proprietary information of
# Majormode or one of its subsidiaries.  You shall not disclose this
# confidential information and shall use it only in accordance with the
# terms of the license agreement or other applicable agreement you
# entered into with Majormode.
#
# MAJORMODE MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
# OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
# TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE, OR NON-INFRINGEMENT.  MAJORMODE SHALL NOT BE LIABLE FOR ANY
# LOSSES OR DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
# OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.

from majormode.perseus.model.enum import Enum


CiCoAction = Enum(
    'checkin',
    'checkout',
)

CiCoMode = Enum(
    # Indicate that the Ci/Co action has been performed automatically by a
    # ID-R device (scan of the QR code printed on a ID card, read of the tag
    # of a NFC/RFID card, face recognition, fingerprint recognition, ...).
    # This Ci/Co operation is considered as secured.
    'automatic',

    # Indicate that the Ci/Co action has been performed manually by an
    # attendant or a security guard by selecting the child on a list and
    # by clicking on a Ci/Co action.  This Ci/Co operation is not considered
    # as secured.  It must be reported to the administrators of organizations
    # responsible for the security of the children.
    'manual',

    # Indicate that the Ci/Co action has been performed by a sentinel
    # responsible for tracking children who are abnormally checked in for a
    # long time (i.e., the child has never been checked-out).  The sentinel
    # checks out such a child and reports this security breach to the
    # administrators of organizations responsible for the security of the
    # children.
    'sentinel',
)

CiCoStatus = Enum(
    'checked_in',
    'checked_out',
)

InvalidCiCoActionReason = Enum(
    # Indicate that the security guard uses an ID-R idr_device that doesn't
    # belong to the school that employs the security guard.  The ID-R idr_device
    # application SHOULD inform the security guard and log him out.
    'wrong_idr_device',

    # Indicate that the ID-R idr_device used to check-in/check-out a child is
    # too far from the school it belongs to.  The ID-R idr_device application
    # SHOULD request the security guard and do not proceed any check-in/
    # check-out operation until the ID-R idr_device is located near the school.
    'wrong_location',

    # Indicate that the child who is being checked-in / checked-out by an
    # ID-R idr_device is not registered to the school that owns this idr_device.
    'wrong_child',

    # Indicate that a guardian of the child MUST be identified to perform
    # the check-out of this child.
    'missing_guardian',

    # Indicate that the person that has been scanned is not a guardian of
    # the child that is checked-out.
    'wrong_guardian',
)



# Copyright (C) 2021 Majormode.  All rights reserved.
#
# This software is the confidential and proprietary information of
# Majormode or one of its subsidiaries.  You shall not disclose this
# confidential information and shall use it only in accordance with the
# terms of the license agreement or other applicable agreement you
# entered into with Majormode.
#
# MAJORMODE MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
# OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
# TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE, OR NON-INFRINGEMENT.  MAJORMODE SHALL NOT BE LIABLE FOR ANY
# LOSSES OR DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
# OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.

from majormode.perseus.model.enum import Enum


AdminNotification = Enum(
    # Direct message sent by a member of an organization responsible for
    # the transportation service of a school, to the guardian of one or more
    # children.
    'on_direct_message',
)


SchoolBusNotification = Enum(
    # Indicate that an attendant checked in or checked out a child who got
    # on or got off their school bus.
    'on_child_school_bus_cico',
)



# Copyright (C) 2020 Majormode.  All rights reserved.
#
# This software is the confidential and proprietary information of
# Majormode or one of its subsidiaries.  You shall not disclose this
# confidential information and shall use it only in accordance with the
# terms of the license agreement or other applicable agreement you
# entered into with Majormode.
#
# MAJORMODE MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
# OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
# TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE, OR NON-INFRINGEMENT.  MAJORMODE SHALL NOT BE LIABLE FOR ANY
# LOSSES OR DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
# OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.

from __future__ import annotations

from uuid import UUID

from majormode.perseus.model.date import ISO8601DateTime
from majormode.perseus.model.geolocation import GeoPoint
from majormode.perseus.utils import cast
from majormode.xebus.constant.cico import CiCoAction
from majormode.xebus.constant.cico import CiCoMode


class CiCoOperation:
    """
    A check-in or check-out operation of a child

    A child is checked in or checked out by an agent (e.g., an attendant,
    a security guard) while the child is getting on/off a school bus, or
    while the child is entering or leaving the school campus.
    """
    def __init__(
            self,
            child_account_id: UUID,
            agent_account_id: UUID,
            device_id: str,
            cico_action: CiCoAction,
            cico_mode: CiCoMode,
            cico_time: ISO8601DateTime,
            guardian_account_id: UUID = None,
            location: GeoPoint = None,
            school_id: UUID = None):
        """
        Build a new object `CiCoOperation`


        :param child_account_id: The identification of the child whom the
            attendant performed a Ci/Co operation.

        :param agent_account_id: Identification of the agent (e.g., an
            attendant, a security guard) who performed this Ci/Co operation.

        :param device_id: Identification of the ID-R device that the attendant
            used to perform this Ci/Co operation.

        :param cico_action: An item of the enumeration `CiCoAction` that
            indicates the action automatically selected or manually overridden
            by the attendant to perform this Ci/Co operation.

        :param cico_mode: An item of the enumeration `CiCoMode` that indicates
            the mode used by the attendant to perform this Ci/Co operation.

        :param cico_time: Time when the attendant performed this Ci/Co
            operation.

        :param guardian_account_id: The identification of a guardian who
            picked up the child from the school bus or the school campus.

        :param location: An object `GeoPoint` that corresponds to the last
            known geographical location of the ID-R mobile device when the
            attendant performed this Ci/Co operation.

        :param school_id: Identification of the school of the child who has
            been checked-in or checked-out.
        """
        self.__child_account_id = child_account_id
        self.__agent_account_id = agent_account_id
        self.__guardian_account_id = guardian_account_id
        self.__device_id = device_id
        self.__cico_action = cico_action
        self.__cico_mode = cico_mode
        self.__cico_time = cico_time
        self.__location = location
        self.__school_id = school_id

    @property
    def agent_account_id(self) -> UUID:
        return self.__agent_account_id

    @property
    def child_account_id(self) -> UUID:
        return self.__child_account_id

    @property
    def cico_action(self) -> CiCoAction:
        return self.__cico_action

    @property
    def cico_mode(self) -> CiCoMode:
        return self.__cico_mode

    @property
    def cico_time(self) -> ISO8601DateTime:
        return self.__cico_time

    @property
    def device_id(self) -> str:
        return self.__device_id

    @property
    def guardian_account_id(self) -> UUID | None:
        return self.__guardian_account_id

    @property
    def location(self) -> GeoPoint | None:
        return self.__location

    @property
    def school_id(self) -> UUID | None:
        return self.__school_id

    @staticmethod
    def from_json(payload) -> CiCoOperation | None:
        return payload and CiCoOperation(
            cast.string_to_uuid(payload['child_account_id']),
            cast.string_to_uuid(payload['agent_account_id']),
            payload['device_id'],
            cast.string_to_enum(payload['cico_action'], CiCoAction),
            cast.string_to_enum(payload['cico_mode'], CiCoMode),
            cast.string_to_timestamp(payload['cico_time']),
            guardian_account_id=cast.string_to_uuid(payload.get('guardian_account_id')),
            location=GeoPoint.from_json(payload.get('location')),
            school_id=cast.string_to_uuid(payload.get('school_id'))
        )



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['majormode',
 'majormode.xebus',
 'majormode.xebus.constant',
 'majormode.xebus.model',
 'majormode.xebus.utils']

package_data = \
{'': ['*']}

install_requires = \
['mercurius-core-library>=1.0,<2.0', 'perseus-core-library>=1.19,<2.0']

setup_kwargs = {
    'name': 'xebus-core-library',
    'version': '1.4.6',
    'description': 'Xebus Core Python Library',
    'long_description': '# Xebus Core Python Library\n\nXebus Core Python Library is a repository of reusable Python components to be shared by Python projects using the Xebus RESTful API.\n\nThese components have minimal dependencies on other libraries, so that they can be deployed easily.  In addition, these components will keep their interfaces as stable as possible, so that other Python projects can integrate these components without having to worry about changes in the future.\n',
    'author': 'Daniel CAUNE',
    'author_email': 'daniel.caune@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/xebus/xebus-core-python-library',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
